.. _contributing-translations:

*************************
Contributing translations
*************************

For translators we have a `Transifex account
<https://www.transifex.com/divio/django-cms/>`_ where you can translate
the ``.po`` files and don't need to install git or mercurial to be able to
contribute. All changes there will be automatically sent to the project.

    .. raw:: html

        Top translations django-cms core:<br/>

        <img border="0" src="https://www.transifex.com/divio/django-cms/resource/core/chart/image_png"/>
